@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -24,18 +24,21 @@ import javax.enterprise.context.SessionScoped;
 
 @SessionScoped
 public class UploadedDocumentManager implements Serializable {
+
     protected Map<String, File> uploadedFiles = new HashMap<>();
 
-    public void uploadFile( String name, File file ) {
-        uploadedFiles.put( name, file );
+    public void uploadFile(String name,
+                           File file) {
+        uploadedFiles.put(name,
+                          file);
     }
 
-    public File getFile( String name ) {
-        return uploadedFiles.get( name );
+    public File getFile(String name) {
+        return uploadedFiles.get(name);
     }
 
-    public void removeFile( String name ) {
-        File file = uploadedFiles.remove( name );
+    public void removeFile(String name) {
+        File file = uploadedFiles.remove(name);
         file.delete();
     }
 }
