@@ -18,15 +18,22 @@ package org.kie.workbench.common.forms.dynamic.client.service;
 import java.util.Collection;
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.ApplicationScoped;
+import javax.inject.Inject;
 
 import org.jboss.errai.ioc.client.container.IOC;
 import org.jboss.errai.ioc.client.container.SyncBeanDef;
 import org.kie.workbench.common.forms.fields.shared.AbstractFieldManager;
 import org.kie.workbench.common.forms.fields.shared.FieldProvider;
+import org.kie.workbench.common.forms.service.shared.meta.processing.MetaDataEntryManager;
 
 @ApplicationScoped
 public class ClientFieldManagerImpl extends AbstractFieldManager {
 
+    @Inject
+    public ClientFieldManagerImpl(MetaDataEntryManager metaDataEntryManager) {
+        super(metaDataEntryManager);
+    }
+
     @PostConstruct
     protected void init() {
         Collection<SyncBeanDef<FieldProvider>> providers = IOC.getBeanManager().lookupBeans(FieldProvider.class);
