@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,5 +17,7 @@
 package org.kie.workbench.common.forms.processing.engine.handling;
 
 public interface FieldChangeHandler {
-    public void onFieldChange( String fieldName, Object newValue );
+
+    public void onFieldChange(String fieldName,
+                              Object newValue);
 }
