@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,9 +16,12 @@
 
 package org.kie.workbench.common.forms.processing.engine.handling;
 
+import java.util.Collection;
+
 import com.google.gwt.user.client.ui.IsWidget;
 
 public interface FormField {
+
     public static final String FORM_GROUP_SUFFIX = "_form_group";
     public static final String HELP_BLOCK_SUFFIX = "_help_block";
 
@@ -30,17 +33,21 @@ public interface FormField {
 
     boolean isBindable();
 
-    void setVisible( boolean visible );
+    void setVisible(boolean visible);
 
-    void setReadOnly( boolean readOnly );
+    void setReadOnly(boolean readOnly);
+
+    boolean isRequired();
 
     void clearError();
 
-    void setError( String error );
+    void setError(String error);
 
     IsWidget getWidget();
 
     default boolean isContentValid() {
         return true;
-    };
+    }
+
+    Collection<FieldChangeListener> getChangeListeners();
 }
