@@ -21,23 +21,26 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Set;
 import java.util.TreeSet;
 import java.util.stream.Collectors;
+import javax.annotation.PostConstruct;
 import javax.annotation.PreDestroy;
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.jboss.errai.ioc.client.container.IOC;
+import org.jboss.errai.ioc.client.container.SyncBeanDef;
 import org.kie.workbench.common.forms.editor.client.editor.rendering.EditorFieldLayoutComponent;
 import org.kie.workbench.common.forms.editor.model.FormModelerContent;
 import org.kie.workbench.common.forms.editor.service.shared.FormEditorRenderingContext;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.HasPlaceHolder;
-import org.kie.workbench.common.forms.model.DynamicModel;
 import org.kie.workbench.common.forms.model.FieldDefinition;
+import org.kie.workbench.common.forms.model.FieldType;
 import org.kie.workbench.common.forms.model.FormDefinition;
 import org.kie.workbench.common.forms.model.FormModel;
-import org.kie.workbench.common.forms.model.HasFormModelProperties;
 import org.kie.workbench.common.forms.service.shared.FieldManager;
 import org.uberfire.commons.data.Pair;
 
@@ -56,6 +59,20 @@ public class FormEditorHelper {
 
     protected Map<String, Pair<EditorFieldLayoutComponent, FieldDefinition>> unbindedFields = new HashMap<>();
 
+    protected Collection<FieldType> enabledPaletteFieldTypes = new ArrayList<>();
+    protected Collection<FieldType> enabledFieldPropertiesFieldTypes = new ArrayList<>();
+
+    @PostConstruct
+    public void init() {
+        Collection<SyncBeanDef<EditorFieldTypesProvider>> providers = IOC.getBeanManager().lookupBeans(EditorFieldTypesProvider.class);
+        providers.stream().map(SyncBeanDef::getInstance)
+                .sorted((EditorFieldTypesProvider providerA, EditorFieldTypesProvider providerB) -> providerA.getPriority() - providerB.getPriority())
+                .forEach((EditorFieldTypesProvider editorProvider) -> {
+                    enabledPaletteFieldTypes.addAll(editorProvider.getPaletteFieldTypes());
+                    enabledFieldPropertiesFieldTypes.addAll(editorProvider.getFieldPropertiesFieldTypes());
+                });
+    }
+
     @Inject
     public FormEditorHelper(FieldManager fieldManager,
                             ManagedInstance<EditorFieldLayoutComponent> editorFieldLayoutComponents) {
@@ -74,10 +91,10 @@ public class FormEditorHelper {
             return;
         }
 
-        for (String baseType : fieldManager.getBaseFieldTypes()) {
+        for (FieldType baseType : enabledPaletteFieldTypes) {
             EditorFieldLayoutComponent layoutComponent = editorFieldLayoutComponents.get();
             if (layoutComponent != null) {
-                FieldDefinition field = fieldManager.getDefinitionByFieldTypeName(baseType);
+                FieldDefinition field = fieldManager.getDefinitionByFieldType(baseType);
                 field.setName(generateUnboundFieldName(field));
 
                 layoutComponent.init(content.getRenderingContext(),
@@ -88,7 +105,7 @@ public class FormEditorHelper {
                                               field));
             }
         }
-        addAvailableFields(content.getAvailableFields());
+        addAvailableFields();
     }
 
     public FormDefinition getFormDefinition() {
@@ -99,10 +116,15 @@ public class FormEditorHelper {
         return getFormDefinition().getModel();
     }
 
-    public void addAvailableFields(List<FieldDefinition> fields) {
-        for (FieldDefinition field : fields) {
-            addAvailableField(field);
-        }
+    public void addAvailableFields() {
+        FormModel model = getFormModel();
+        FormDefinition formDefinition = getFormDefinition();
+
+        model.getProperties().forEach(modelProperty -> {
+            if(formDefinition.getFieldByBinding(modelProperty.getName()) == null) {
+                addAvailableField(fieldManager.getDefinitionByModelProperty(modelProperty));
+            }
+        });
     }
 
     public void addAvailableField(FieldDefinition field) {
@@ -121,9 +143,8 @@ public class FormEditorHelper {
         if (result == null) {
 
             result = availableFields.get(fieldId);
-            if (result != null) {
-                availableFields.remove(fieldId);
-            } else {
+
+            if (result == null) {
                 if (unbindedFields.containsKey(fieldId)) {
                     Pair<EditorFieldLayoutComponent, FieldDefinition> pair = unbindedFields.get(fieldId);
 
@@ -149,9 +170,6 @@ public class FormEditorHelper {
                                                   newField));
                 }
             }
-            if (result != null) {
-                content.getDefinition().getFields().add(result);
-            }
         }
         return result;
     }
@@ -177,73 +195,74 @@ public class FormEditorHelper {
     public boolean modelContainsField(FieldDefinition fieldDefinition) {
         FormModel formModel = getFormModel();
 
-        if (formModel instanceof HasFormModelProperties) {
-            return ((HasFormModelProperties) formModel).getProperty(fieldDefinition.getBinding()) != null;
-        }
-        return false;
+        return formModel.getProperty(fieldDefinition.getBinding()) != null;
     }
 
     public List<String> getCompatibleModelFields(FieldDefinition field) {
-        Collection<String> compatibles = fieldManager.getCompatibleFields(field);
+        Collection<String> compatibles = fieldManager.getCompatibleTypes(field);
 
         Set<String> result = new TreeSet<>();
         if (field.getBinding() != null && !field.getBinding().isEmpty()) {
             result.add(field.getBinding());
         }
-        for (String compatibleType : compatibles) {
-            for (FieldDefinition definition : availableFields.values()) {
-                if (definition.getFieldType().getTypeName().equals(compatibleType) && definition.getBinding() != null) {
-                    result.add(definition.getBinding());
-                }
-            }
-        }
+
+        availableFields.values().stream().filter(availableField -> compatibles.contains(availableField.getStandaloneClassName())).forEach(availableField -> result.add(availableField.getBinding()));
+
         return new ArrayList<>(result);
     }
 
     public List<String> getCompatibleFieldTypes(FieldDefinition field) {
-        return new ArrayList<>(fieldManager.getCompatibleFields(field));
+        List<String> editorFieldTypeCodes = enabledFieldPropertiesFieldTypes.stream().map(FieldType::getTypeName).collect(Collectors.toList());
+        return fieldManager.getCompatibleFields(field).stream().filter((fieldCode) -> editorFieldTypeCodes.contains(fieldCode))
+                .collect(Collectors.toList());
     }
 
     public FieldDefinition switchToField(FieldDefinition originalField,
-                                         String bindingExpression) {
+                                         String newBinding) {
 
-        FieldDefinition resultField = fieldManager.getDefinitionByFieldTypeName(originalField.getFieldType().getTypeName());
+        if (newBinding != null && !"".equals(newBinding)) {
+            Optional<FieldDefinition> availableFieldOptional = availableFields.values()
+                    .stream()
+                    .filter(availableField -> availableField.getBinding().equals(newBinding)).findFirst();
 
-        if (bindingExpression == null || bindingExpression.equals("") || content.getDefinition().getFieldByBinding(bindingExpression) != null) {
-            resultField.setName(generateUnboundFieldName(resultField));
-            resultField.setBinding("");
-        } else {
-            // Search if there's an available field with the specified binding
-            for (Iterator<FieldDefinition> it = availableFields.values().iterator(); it.hasNext(); ) {
-                FieldDefinition availableField = it.next();
-                if (availableField.getBinding().equals(bindingExpression)) {
+            if (availableFieldOptional.isPresent()) {
+                FieldDefinition availableField = availableFieldOptional.get();
 
-                    // Check types if we are binding a fields on dynamicModel && change field type if needed
-                    if (content.getDefinition().getModel() instanceof DynamicModel && !resultField.getFieldType().equals(availableField.getFieldType())) {
-                        resultField = fieldManager.getFieldFromProvider(availableField.getFieldType().getTypeName(),
-                                                                        availableField.getFieldTypeInfo());
-                    }
+                FieldDefinition resultField = fieldManager.getFieldFromProvider(originalField.getFieldType().getTypeName(),
+                                                                                availableField.getFieldTypeInfo());
 
-                    resultField.setId(availableField.getId());
-                    resultField.setName(availableField.getName());
-
-                    resultField.copyFrom(availableField);
-
-                    return resultField;
+                if (resultField == null) {
+                    // this happens when trying to bind to a property which is of an unsupported type for the current FieldFefintion
+                    resultField = fieldManager.getFieldFromProvider(availableField.getFieldType().getTypeName(),
+                                                                    availableField.getFieldTypeInfo());
                 }
+
+                resultField.copyFrom(originalField);
+
+                resultField.setId(availableField.getId());
+                resultField.setName(availableField.getName());
+                resultField.setStandaloneClassName(availableField.getStandaloneClassName());
+                resultField.setBinding(newBinding);
+
+                return resultField;
             }
         }
 
         // If we arrive here is because we have a dynamic binding or we are unbinding a field
+        FieldDefinition resultField = fieldManager.getDefinitionByFieldTypeName(originalField.getFieldType().getTypeName());
+
+        if (newBinding == null || newBinding.equals("")) {
+            // unbinding a field
+            resultField.setName(generateUnboundFieldName(resultField));
+            resultField.setBinding("");
+        }
+
         resultField.copyFrom(originalField);
-        resultField.setBinding(bindingExpression);
+        resultField.setBinding(newBinding);
 
         if (resultField.getName() == null) {
-            String name = bindingExpression;
-            if (name == null || name.isEmpty()) {
-                name = generateUnboundFieldName(resultField);
-            }
-            resultField.setName(name);
+            // edge case we only get here with dynamic bindings
+            resultField.setName(newBinding);
         }
 
         return resultField;
@@ -264,6 +283,18 @@ public class FormEditorHelper {
         return resultDefinition;
     }
 
+    public void saveFormField(FieldDefinition originalField,
+                              FieldDefinition fieldCopy) {
+        if (originalField.getBinding() != null && !originalField.getBinding().equals(fieldCopy.getBinding())) {
+            addAvailableField(originalField);
+        }
+        if (fieldCopy.getBinding() != null && !fieldCopy.getBinding().isEmpty()) {
+            removeAvailableField(fieldCopy);
+        }
+        content.getDefinition().getFields().remove(originalField);
+        content.getDefinition().getFields().add(fieldCopy);
+    }
+
     public String generateUnboundFieldName(FieldDefinition field) {
         return UNBOUND_FIELD_NAME_PREFFIX + field.getId();
     }
