@@ -23,7 +23,7 @@ import java.util.Map;
 
 import com.google.gwtmockito.GwtMock;
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.apache.deltaspike.core.util.StringUtils;
+import org.assertj.core.api.Assertions;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
@@ -38,6 +38,9 @@ import org.kie.workbench.common.forms.editor.service.shared.FormEditorRenderingC
 import org.kie.workbench.common.forms.editor.service.shared.FormEditorService;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.checkBox.definition.CheckBoxFieldDefinition;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.datePicker.definition.DatePickerFieldDefinition;
+import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.decimalBox.definition.DecimalBoxFieldDefinition;
+import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.integerBox.definition.IntegerBoxFieldDefinition;
+import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.slider.definition.IntegerSliderDefinition;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textArea.definition.TextAreaFieldDefinition;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textBox.definition.TextBoxFieldDefinition;
 import org.kie.workbench.common.forms.fields.test.TestFieldManager;
@@ -48,7 +51,6 @@ import org.kie.workbench.common.forms.model.impl.ModelPropertyImpl;
 import org.kie.workbench.common.forms.model.impl.PortableJavaModel;
 import org.kie.workbench.common.forms.model.impl.TypeInfoImpl;
 import org.mockito.Mock;
-import org.mockito.Spy;
 import org.uberfire.commons.data.Pair;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.plugin.client.perspective.editor.layout.editor.HTMLLayoutDragComponent;
@@ -60,14 +62,22 @@ import static org.mockito.Mockito.*;
 @RunWith(GwtMockitoTestRunner.class)
 public class FormEditorHelperTest {
 
+    public static final String DYNAMIC_BINDING = "dynamicBinding";
+
     private List<FieldDefinition> employeeFields;
 
     private List<ModelProperty> modelProperties;
 
     private FieldDefinition nameField;
 
+    private TextBoxFieldDefinition lastNameField;
+
     private FieldDefinition marriedField;
 
+    private IntegerBoxFieldDefinition ageField;
+
+    private DecimalBoxFieldDefinition weightField;
+
     private TestFormEditorHelper formEditorHelper;
 
     @Mock
@@ -94,7 +104,6 @@ public class FormEditorHelperTest {
     @Mock
     private FormDefinition formDefinition;
 
-    @Spy
     private TestFieldManager testFieldManager;
 
     private CallerMock<FormEditorService> editorServiceCallerMock;
@@ -109,6 +118,8 @@ public class FormEditorHelperTest {
 
     private void loadContent() {
 
+        testFieldManager = spy(new TestFieldManager());
+
         when(editorFieldLayoutComponents.get()).thenAnswer(invocationOnMock -> {
             final EditorFieldLayoutComponent mocked = mock(EditorFieldLayoutComponent.class);
             return mocked;
@@ -121,18 +132,14 @@ public class FormEditorHelperTest {
 
             content = new FormModelerContent();
 
-            content.getModelProperties().addAll(modelProperties);
-
             PortableJavaModel model = new PortableJavaModel("com.test.Employee");
+
             model.getProperties().addAll(modelProperties);
 
             form.setModel(model);
 
-            model.getProperties().addAll(modelProperties);
-
             content.setDefinition(form);
             content.setOverview(new Overview());
-            content.setAvailableFields(employeeFields);
 
             return content;
         });
@@ -151,6 +158,9 @@ public class FormEditorHelperTest {
 
         formEditorService.loadContent(null);
         formEditorHelper.initHelper(content);
+
+        assertEquals(formEditorHelper.getEditorFieldTypes().size(),
+                     formEditorHelper.getBaseFieldsDraggables().size());
     }
 
     @Test
@@ -200,11 +210,18 @@ public class FormEditorHelperTest {
 
     @Test
     public void testGetFormFieldAvailable() {
-        formEditorHelper.addAvailableField(nameField);
-        formEditorHelper.getFormField(nameField.getId());
-        assertEquals("If the field should be no more available!",
-                     formEditorHelper.getAvailableFields().size(),
-                     employeeFields.size() - 1);
+        FieldDefinition resultField = formEditorHelper.getAvailableFields().values().stream().filter( fieldDefinition -> fieldDefinition.getBinding().equals(nameField.getBinding())).findFirst().get();
+
+        formEditorHelper.saveFormField(nameField,
+                                       resultField);
+
+        Assertions.assertThat(resultField)
+                .isNotNull()
+                .isEqualToComparingOnlyGivenFields(nameField, "name", "binding", "standaloneClassName");
+
+        Assertions.assertThat(content.getDefinition().getFieldById(resultField.getId())).isNotNull();
+
+        Assertions.assertThat(formEditorHelper.getAvailableFields().size()).isEqualTo(employeeFields.size() - 1);
     }
 
     @Test
@@ -218,18 +235,17 @@ public class FormEditorHelperTest {
 
         FieldDefinition expectedField = pair.getK2();
 
-        assertNotNull(expectedField);
+        Assertions.assertThat(expectedField).isNotNull();
 
         FieldDefinition resultField = formEditorHelper.getFormField(expectedField.getId());
+        formEditorHelper.saveFormField(expectedField,
+                                       resultField);
 
-        assertNotNull(resultField);
-        assertSame(expectedField,
-                   resultField);
-        assertEquals(resultField.getFieldType().getTypeName(),
-                     resultField.getLabel());
+        Assertions.assertThat(resultField).isNotNull().isEqualTo(expectedField);
+        Assertions.assertThat(resultField.getFieldType().getTypeName()).isEqualTo(resultField.getLabel());
 
-        assertNotNull(content.getDefinition().getFieldById(resultField.getId()));
-        assertNull(formEditorHelper.getUnbindedFields().get(resultField.getId()));
+        Assertions.assertThat(content.getDefinition().getFieldById(resultField.getId())).isNotNull();
+        Assertions.assertThat(formEditorHelper.getUnbindedFields().get(resultField.getId())).isNull();
     }
 
     @Test
@@ -244,17 +260,8 @@ public class FormEditorHelperTest {
         formEditorHelper.addAvailableField(employeeFields.get(0));
         Map<String, FieldDefinition> availableFields = formEditorHelper.getAvailableFields();
         assertEquals("The added field should be returned in available fields",
-                     availableFields.size(),
-                     employeeFields.size());
-    }
-
-    @Test
-    public void testAddAvailableFields() {
-        formEditorHelper.addAvailableFields(employeeFields);
-        Map<String, FieldDefinition> availableFields = formEditorHelper.getAvailableFields();
-        assertEquals("The added field should be returned in available fields",
-                     availableFields.size(),
-                     employeeFields.size());
+                     employeeFields.size() + 1,
+                     availableFields.size());
     }
 
     @Test
@@ -299,10 +306,37 @@ public class FormEditorHelperTest {
     }
 
     @Test
-    public void testGetCompatibleFieldCodes() {
-        List<String> compatibleFieldIds = formEditorHelper.getCompatibleModelFields(nameField);
-        assertTrue(compatibleFieldIds.size() > 0);
-        assertTrue(compatibleFieldIds.contains(nameField.getId()));
+    public void testGetCompatibleModelFields() {
+        List<String> compatibleModelFields = formEditorHelper.getCompatibleModelFields(nameField);
+        assertEquals(2,
+                     compatibleModelFields.size());
+        Assertions.assertThat(compatibleModelFields).containsExactly(lastNameField.getId(),
+                                                                     nameField.getId());
+
+        // Getting compatible model propertynames for an integerbox field -> only checks integer properties (age -> integer)
+        compatibleModelFields = formEditorHelper.getCompatibleModelFields(ageField);
+        assertEquals(1,
+                     compatibleModelFields.size());
+        Assertions.assertThat(compatibleModelFields).containsOnly(ageField.getId());
+
+        // Getting compatible model propertynames for an decimalbox field -> only checks decimal properties (weight -> double)
+        compatibleModelFields = formEditorHelper.getCompatibleModelFields(weightField);
+        assertEquals(1,
+                     compatibleModelFields.size());
+        Assertions.assertThat(compatibleModelFields).containsOnly(weightField.getId());
+
+        IntegerSliderDefinition slider = new IntegerSliderDefinition();
+        slider.setId("slider");
+        slider.setName("slider");
+        slider.setLabel("slider");
+
+        // Getting compatible model propertynames for an integer slider field -> slider's are available for integer &
+        // decimal properties (age -> integer & weight -> double)
+        compatibleModelFields = formEditorHelper.getCompatibleModelFields(slider);
+        assertEquals(2,
+                     compatibleModelFields.size());
+        Assertions.assertThat(compatibleModelFields).containsExactly(ageField.getId(),
+                                                                     weightField.getId());
     }
 
     @Test
@@ -312,27 +346,44 @@ public class FormEditorHelperTest {
     }
 
     @Test
-    public void testSwitchToFieldNull() {
-        testSwitchToField(null);
+    public void testSwitchToNullBinding() {
+        FieldDefinition result = formEditorHelper.switchToField(nameField,
+                                                                null);
+
+        Assertions.assertThat(result.getId()).isNotEqualTo(nameField.getId());
+        Assertions.assertThat(result.getName()).isNotEqualTo(nameField.getName());
+        Assertions.assertThat(result.getBinding()).isNullOrEmpty();
+        Assertions.assertThat(result.getBinding()).isNotEqualTo(nameField.getBinding());
+        Assertions.assertThat(result.getStandaloneClassName()).isEqualTo(nameField.getStandaloneClassName());
     }
 
     @Test
-    public void testSwitchToFieldNotNull() {
-        testSwitchToField(nameField.getBinding());
+    public void testSwitchToFieldBinding() {
+        testSwitchToField(nameField,
+                          lastNameField);
+        testSwitchToField(nameField,
+                          marriedField);
     }
 
-    public void testSwitchToField(String fieldCode) {
-        when(testFieldManager.getDefinitionByFieldTypeName(anyString()))
-                .thenReturn(nameField);
-        formEditorHelper.addAvailableFields(employeeFields);
-        FieldDefinition fieldDefinition = formEditorHelper.switchToField(nameField,
-                                                                         fieldCode);
-        String expectedFieldName = (StringUtils.isEmpty(fieldCode) ?
-                formEditorHelper.generateUnboundFieldName(nameField) :
-                nameField.getName());
+    @Test
+    public void testSwitchToDynamicBinding() {
+        FieldDefinition result = formEditorHelper.switchToField(nameField,
+                                                                DYNAMIC_BINDING);
 
-        assertEquals(fieldDefinition.getName(),
-                     expectedFieldName);
+        Assertions.assertThat(result.getId()).isNotEqualTo(nameField.getId());
+        Assertions.assertThat(result.getName()).isEqualTo(DYNAMIC_BINDING);
+        Assertions.assertThat(result.getBinding()).isEqualTo(DYNAMIC_BINDING);
+        Assertions.assertThat(result.getStandaloneClassName()).isEqualTo(nameField.getStandaloneClassName());
+    }
+
+    protected void testSwitchToField(FieldDefinition originalField,
+                                     FieldDefinition expectedField) {
+        FieldDefinition result = formEditorHelper.switchToField(originalField,
+                                                                expectedField.getBinding());
+
+        Assertions.assertThat(result)
+                .isNotNull()
+                .isEqualToComparingOnlyGivenFields(expectedField, "name", "binding", "standaloneClassName");
     }
 
     @Test
@@ -351,44 +402,62 @@ public class FormEditorHelperTest {
         assertFalse(formEditorHelper.getAvailableFields().containsKey(nameField.getId()));
     }
 
-    void initFields() {
+    private void initFields() {
         TextBoxFieldDefinition name = new TextBoxFieldDefinition();
         name.setId("name");
-        name.setName("employee_name");
+        name.setName("name");
         name.setLabel("Name");
         name.setPlaceHolder("Name");
         name.setBinding("name");
         name.setStandaloneClassName(String.class.getName());
+
         nameField = name;
 
         TextBoxFieldDefinition lastName = new TextBoxFieldDefinition();
         lastName.setId("lastName");
-        lastName.setName("employee_lastName");
+        lastName.setName("lastName");
         lastName.setLabel("Last Name");
         lastName.setPlaceHolder("Last Name");
         lastName.setBinding("lastName");
         lastName.setStandaloneClassName(String.class.getName());
+        lastNameField = lastName;
 
         DatePickerFieldDefinition birthday = new DatePickerFieldDefinition();
         birthday.setId("birthday");
-        birthday.setName("employee_birthday");
+        birthday.setName("birthday");
         birthday.setLabel("Birthday");
         birthday.setBinding("birthday");
         birthday.setStandaloneClassName(Date.class.getName());
 
         CheckBoxFieldDefinition married = new CheckBoxFieldDefinition();
         married.setId("married");
-        married.setName("employee_married");
+        married.setName("married");
         married.setLabel("Married");
         married.setBinding("married");
         married.setStandaloneClassName(Boolean.class.getName());
         marriedField = married;
 
+        IntegerBoxFieldDefinition age = new IntegerBoxFieldDefinition();
+        age.setId("age");
+        age.setName("age");
+        age.setLabel("Age");
+        age.setBinding("age");
+        ageField = age;
+
+        DecimalBoxFieldDefinition weight = new DecimalBoxFieldDefinition();
+        weight.setId("weight");
+        weight.setName("weight");
+        weight.setLabel("Weight");
+        weight.setBinding("weight");
+        weightField = weight;
+
         employeeFields = new ArrayList<>();
         employeeFields.add(name);
         employeeFields.add(lastName);
         employeeFields.add(birthday);
         employeeFields.add(married);
+        employeeFields.add(age);
+        employeeFields.add(weight);
 
         modelProperties = new ArrayList<>();
 
