@@ -25,12 +25,16 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldLayoutComponent;
 import org.kie.workbench.common.forms.editor.client.editor.events.FormEditorSyncPaletteEvent;
+import org.kie.workbench.common.forms.editor.model.FormModelerContent;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textArea.definition.TextAreaFieldDefinition;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textBox.definition.TextBoxFieldDefinition;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.model.FormDefinition;
 import org.mockito.verification.VerificationMode;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.ext.editor.commons.client.file.CommandWithFileNameAndCommitMessage;
+import org.uberfire.ext.editor.commons.client.file.FileNameAndCommitMessage;
+import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.ext.layout.editor.api.editor.LayoutComponent;
 import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate;
@@ -38,8 +42,24 @@ import org.uberfire.ext.layout.editor.client.api.ComponentRemovedEvent;
 import org.uberfire.mvp.Command;
 import org.uberfire.workbench.model.menu.MenuItem;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Matchers.anyInt;
+import static org.mockito.Matchers.eq;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyBoolean;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.atLeastOnce;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
@@ -160,7 +180,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
 
         FormDefinition form = editorHelper.getFormDefinition();
 
-        addField(editorHelper.getAvailableFields().get(fieldId));
+        addField(editorHelper.getAvailableFields().values().stream().filter(fieldDefinition -> fieldDefinition.getBinding().equals(fieldId)).findFirst().get());
 
         checkExpectedFields(editorHelper.getAvailableFields().size(),
                             1,
@@ -357,8 +377,6 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
     @Test
     public void testLoadAvailableFieldsNoContent() {
         loadContent();
-        when(content.getAvailableFields()).thenReturn(null);
-        FormEditorPresenter presenterSpy = spy(presenter);
 
         presenter.doLoadContent(content);
     }
@@ -366,7 +384,6 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
     @Test
     public void testGetFormTemplate() {
         loadContent();
-        when(content.getAvailableFields()).thenReturn(null);
 
         presenter.getFormTemplate();
 
@@ -398,8 +415,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         verify(menuBuilderMock).addSave(any(MenuItem.class));
         verify(menuBuilderMock).addCopy(any(Path.class),
                                         any(DefaultFileNameValidator.class));
-        verify(menuBuilderMock).addRename(any(Path.class),
-                                          any(DefaultFileNameValidator.class));
+        verify(menuBuilderMock).addRename(any(Command.class));
         verify(menuBuilderMock).addDelete(any(Command.class));
 
         assertNotNull(presenter.getMenus());
@@ -470,4 +486,72 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         verify(view).hideBusyIndicator();
         verify(notificationEvent).fire(any());
     }
+
+    @Test
+    public void testSafeRenameDirtySaving() {
+        FormEditorPresenter presenterSpy = triggerSafeRename(true, true);
+        verify(view).showSavePopup(any(Path.class), any(Command.class), any(Command.class));
+        verify(presenterSpy).rename(eq(true));
+    }
+
+    @Test
+    public void testSafeRenameDirtyNotSaving() {
+        FormEditorPresenter presenterSpy = triggerSafeRename(true, false);
+
+        verify(view).showSavePopup(any(Path.class), any(Command.class), any(Command.class));
+        verify(presenterSpy).rename(eq(false));
+    }
+
+    @Test
+    public void testSafeRenameNotDirty() {
+        FormEditorPresenter presenterSpy = triggerSafeRename(false, false);
+
+        verify(view, never()).showSavePopup(any(Path.class), any(Command.class), any(Command.class));
+        verify(presenterSpy).rename(eq(false));
+    }
+
+    private FormEditorPresenter triggerSafeRename(boolean dirty, boolean saving) {
+        loadContent();
+        FormEditorPresenter presenterSpy = spy(presenter);
+        doNothing().when(presenterSpy).rename(anyBoolean());
+        doReturn(dirty).when(presenterSpy).isDirty(anyInt());
+
+        presenterSpy.safeRename();
+
+        if (dirty) {
+            presenterSpy.rename(saving);
+        }
+        return presenterSpy;
+    }
+
+    @Test
+    public void testRenameSaving() {
+        testRename(true);
+    }
+
+    @Test
+    public void testRenameNotSaving() {
+        testRename(false);
+    }
+
+    private void testRename(boolean saving) {
+        loadContent();
+        presenter.rename(saving);
+        verify(renamePopUpPresenter).show(any(Path.class), any(DefaultFileNameValidator.class), any(CommandWithFileNameAndCommitMessage.class));
+    }
+
+    @Test
+    public void testRenameCommand() {
+        loadContent();
+        FormEditorPresenter presenterSpy = spy(presenter);
+        FileNameAndCommitMessage details = mock(FileNameAndCommitMessage.class);
+        when(renamePopUpPresenter.getView()).thenReturn(mock(RenamePopUpPresenter.View.class));
+        doNothing().when(presenterSpy).doLoadContent(any(FormModelerContent.class));
+
+        presenterSpy.renameCommand(details, true);
+
+        verify(view).showBusyIndicator(anyString());
+        verify(presenterSpy).getRenameErrorCallback(any(RenamePopUpPresenter.View.class));
+        verify(presenterSpy).getRenameSuccessCallback(any(RenamePopUpPresenter.View.class));
+    }
 }
