@@ -21,7 +21,6 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.editor.client.editor.properties.binding.DataBinderEditorTest;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
-import org.uberfire.mvp.Command;
 
 import static org.mockito.Mockito.*;
 
@@ -43,16 +42,19 @@ public class DynamicDataBinderEditorTest extends DataBinderEditorTest<DynamicDat
         editor.setUp();
         verify(view).init(editor);
 
-        editor.init(helper,
-                    FIELD_BINDING,
-                    mock(Command.class));
+        editor.init(fieldDefinition,
+                    bindingsSupplier,
+                    bindingChangeConsumer);
 
         verify(view).clear();
 
+        verify(bindingsSupplier,
+               never()).get();
+
         verify(view).setFieldBinding(FIELD_BINDING);
 
         editor.onBindingChange();
-        verify(editor.onChangeCallback).execute();
+        verify(bindingChangeConsumer).accept(any());
 
         editor.getElement();
         verify(view).getElement();
