@@ -21,7 +21,6 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.editor.client.editor.properties.binding.DataBinderEditorTest;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
-import org.uberfire.mvp.Command;
 
 import static org.mockito.Matchers.anyBoolean;
 import static org.mockito.Matchers.anyString;
@@ -31,7 +30,7 @@ import static org.mockito.Mockito.*;
 public class StaticDataBinderEditorTest extends DataBinderEditorTest<StaticDataBinderEditor> {
 
     @Mock
-    protected StaticDataBinderEditorView view;
+    private StaticDataBinderEditorView view;
 
     @Override
     public void initTest() {
@@ -42,15 +41,21 @@ public class StaticDataBinderEditorTest extends DataBinderEditorTest<StaticDataB
 
     @Test
     public void testFunctionallity() {
+        when(fieldDefinition.getBinding()).thenReturn(NAME);
+
         editor.setUp();
+
         verify(view).init(editor);
 
-        editor.init(helper,
-                    NAME,
-                    mock(Command.class));
+        editor.init(fieldDefinition,
+                    bindingsSupplier,
+                    bindingChangeConsumer);
+        ;
 
         verify(view).clear();
 
+        verify(bindingsSupplier).get();
+
         verify(view,
                times(fields.size() + 1)).addModelField(anyString(),
                                                        anyBoolean());
@@ -61,7 +66,7 @@ public class StaticDataBinderEditorTest extends DataBinderEditorTest<StaticDataB
         });
 
         editor.onBindingChange();
-        verify(editor.onChangeCallback).execute();
+        verify(bindingChangeConsumer).accept(any());
 
         editor.getElement();
         verify(view).getElement();
