@@ -40,6 +40,7 @@ import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textBox.def
 import org.kie.workbench.common.forms.fields.test.TestFieldManager;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.model.FormDefinition;
+import org.kie.workbench.common.forms.model.FormModel;
 import org.kie.workbench.common.forms.model.TypeInfo;
 import org.kie.workbench.common.forms.service.shared.FieldManager;
 import org.mockito.Mock;
@@ -96,6 +97,9 @@ public class EditorFieldLayoutComponentTest {
     @Mock
     private FormDefinition formDefinition;
 
+    @Mock
+    private FormModel formModel;
+
     private FieldDefinition fieldDefinition;
 
     private LayoutComponent layoutComponent = new LayoutComponent(EditorFieldLayoutComponent.class.getName());
@@ -128,6 +132,7 @@ public class EditorFieldLayoutComponentTest {
 
         when(formDefinition.getId()).thenReturn(EditorFieldLayoutComponent.FORM_ID);
         when(formDefinition.getFieldById(anyString())).thenReturn(fieldDefinition);
+        when(formDefinition.getModel()).thenReturn(formModel);
         when(context.getRootForm()).thenReturn(formDefinition);
 
         content = new FormModelerContent();
@@ -423,88 +428,4 @@ public class EditorFieldLayoutComponentTest {
         assertFalse(editorFieldLayoutComponent.showProperties);
         verify(ctx).configurationCancelled();
     }
-
-    @Test
-    public void testIsBindingChangeBothSame() {
-        testIsBindingChange(BINDING_FIRSTNAME,
-                            BINDING_FIRSTNAME,
-                            true);
-    }
-
-    @Test
-    public void testIsBindingChangeBothNull() {
-        testIsBindingChange(null,
-                            null,
-                            false);
-    }
-
-    @Test
-    public void testIsBindingChangeBothEmpty() {
-        testIsBindingChange("",
-                            "",
-                            false);
-    }
-
-    @Test
-    public void testIsBindingChangeNullEmpty() {
-        testIsBindingChange(null,
-                            "",
-                            false);
-    }
-
-    @Test
-    public void testIsBindingChangeEmptyNull() {
-        testIsBindingChange("",
-                            null,
-                            false);
-    }
-
-    @Test
-    public void testIsBindingChangeEmptyPopulated() {
-        testIsBindingChange("",
-                            BINDING_FIRSTNAME,
-                            true);
-    }
-
-    @Test
-    public void testIsBindingChangeNullPopulated() {
-        testIsBindingChange(null,
-                            BINDING_FIRSTNAME,
-                            true);
-    }
-
-    @Test
-    public void testIsBindingChangePopulatedEmpty() {
-        testIsBindingChange(BINDING_FIRSTNAME,
-                            "",
-                            true);
-    }
-
-    @Test
-    public void testIsBindingChangePopulatedNull() {
-        testIsBindingChange(BINDING_FIRSTNAME,
-                            null,
-                            true);
-    }
-
-    @Test
-    public void testIsBindingChangeBothPopulated() {
-        testIsBindingChange(BINDING_FIRSTNAME,
-                            BINDING_LASTNAME,
-                            true);
-    }
-
-    protected void testIsBindingChange(String oldFieldBinding,
-                                       String newFieldBinding,
-                                       boolean expectedChange) {
-        FieldDefinition oldField = new TextBoxFieldDefinition();
-        oldField.setBinding(oldFieldBinding);
-        FieldDefinition newField = new TextBoxFieldDefinition();
-        newField.setBinding(newFieldBinding);
-
-        boolean isChange = editorFieldLayoutComponent.isBindingChange(oldField,
-                                                                      newField);
-        assertEquals(expectedChange,
-                     isChange);
-    }
 }
