@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,10 +20,10 @@ import com.google.gwt.user.client.ui.HasValue;
 import com.google.gwt.user.client.ui.IsWidget;
 import org.kie.workbench.common.forms.dynamic.model.document.DocumentData;
 
-public interface DocumentFieldRendererView extends IsWidget, HasValue<DocumentData> {
+public interface DocumentFieldRendererView extends IsWidget,
+                                                   HasValue<DocumentData> {
 
-    public void setRenderer( DocumentFieldRenderer renderer );
-
-    public void setReadOnly( boolean readOnly );
+    public void setRenderer(DocumentFieldRenderer renderer);
 
+    public void setReadOnly(boolean readOnly);
 }
