@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,16 +17,23 @@
 package org.kie.workbench.common.forms.jbpm.client.resources.i18n;
 
 import org.jboss.errai.ui.shared.api.annotations.TranslationKey;
+import org.kie.workbench.common.forms.jbpm.model.authoring.process.BusinessProcessFormModel;
+import org.kie.workbench.common.forms.jbpm.model.authoring.task.TaskFormModel;
 
 public interface Constants {
 
-    @TranslationKey( defaultValue = "Business Process")
-    public static final String Process = "JBPMFormModelCreationPresenter.Process";
+    @TranslationKey(defaultValue = "Business Process")
+    public static final String Process = BusinessProcessFormModel.class.getName();
 
-    @TranslationKey( defaultValue = "Start Process Form")
+    @TranslationKey(defaultValue = "")
+    public static final String Task = TaskFormModel.class.getName();
+
+    @TranslationKey(defaultValue = "Start Process Form")
     public static final String JBPMFormModelCreationViewImplStartProcessForm = "JBPMFormModelCreationViewImpl.StartProcessForm";
 
-    @TranslationKey( defaultValue = "There's no process or task selected")
-    public static final String InvalidFormModel = "JBPMFormModelCreationPresenter.InvalidFormModel";
+    @TranslationKey(defaultValue = "Form for Task {0} ({1})")
+    public static final String JBPMFormModelCreationViewImplTaskName = "JBPMFormModelCreationViewImpl.TaskName";
 
+    @TranslationKey(defaultValue = "There's no process or task selected")
+    public static final String InvalidFormModel = "JBPMFormModelCreationPresenter.InvalidFormModel";
 }
