@@ -41,6 +41,7 @@ import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryEnvironmentConfigurations;
 import org.guvnor.structure.repositories.RepositoryService;
+import org.guvnor.structure.security.OrganizationalUnitAction;
 import org.jboss.errai.bus.server.annotations.Service;
 import org.kie.workbench.common.screens.examples.model.ExampleOrganizationalUnit;
 import org.kie.workbench.common.screens.examples.model.ExampleProject;
@@ -55,10 +56,11 @@ import org.kie.workbench.common.screens.library.api.LibraryInfo;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.OrganizationalUnitRepositoryInfo;
 import org.kie.workbench.common.screens.library.api.ProjectAssetsQuery;
+import org.kie.workbench.common.screens.library.api.index.LibraryValueFileNameIndexTerm;
 import org.kie.workbench.common.screens.library.api.index.LibraryValueProjectRootPathIndexTerm;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryPreferences;
-import org.kie.workbench.common.services.refactoring.model.index.terms.valueterms.ValueFullFileNameIndexTerm;
+import org.kie.workbench.common.screens.projecteditor.util.NewProjectUtils;
 import org.kie.workbench.common.services.refactoring.model.index.terms.valueterms.ValueIndexTerm;
 import org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRequest;
 import org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRow;
@@ -136,6 +138,10 @@ public class LibraryServiceImpl implements LibraryService {
 
     @Override
     public OrganizationalUnitRepositoryInfo getOrganizationalUnitRepositoryInfo(final OrganizationalUnit selectedOrganizationalUnit) {
+        if (selectedOrganizationalUnit == null) {
+            return null;
+        }
+
         final Repository selectedRepository = getDefaultRepository(selectedOrganizationalUnit);
         final List<OrganizationalUnit> organizationalUnits = getOrganizationalUnits();
         final OrganizationalUnit organizationalUnit = getOrganizationalUnit(selectedOrganizationalUnit.getIdentifier(),
@@ -159,18 +165,18 @@ public class LibraryServiceImpl implements LibraryService {
 
     @Override
     public KieProject createProject(final String projectName,
+                                    final OrganizationalUnit selectedOrganizationalUnit,
                                     final Repository selectedRepository,
                                     final String baseURL,
-                                    final String projectDescription) {
+                                    final String projectDescription,
+                                    final DeploymentMode mode) {
         final Path selectedRepositoryRootPath = selectedRepository.getRoot();
-        final LibraryPreferences preferences = getPreferences();
 
         final GAV gav = createGAV(projectName,
-                                  preferences);
+                                  selectedOrganizationalUnit);
         final POM pom = createPOM(projectName,
                                   projectDescription,
                                   gav);
-        final DeploymentMode mode = DeploymentMode.VALIDATED;
 
         final KieProject kieProject = kieProjectService.newProject(selectedRepositoryRootPath,
                                                                    pom,
@@ -197,13 +203,18 @@ public class LibraryServiceImpl implements LibraryService {
         checkNotNull("query",
                      query);
 
+        final boolean projectStillExists = ioService.exists(Paths.convert(query.getProject().getRootPath()));
+        if (!projectStillExists) {
+            return Collections.emptyList();
+        }
+
         final HashSet<ValueIndexTerm> queryTerms = new HashSet<>();
 
         queryTerms.add(new LibraryValueProjectRootPathIndexTerm(query.getProject().getRootPath().toURI()));
 
         if (query.hasFilter()) {
-            queryTerms.add(new ValueFullFileNameIndexTerm("*" + query.getFilter() + "*",
-                                                          ValueIndexTerm.TermSearchType.WILDCARD));
+            queryTerms.add(new LibraryValueFileNameIndexTerm("*" + query.getFilter() + "*",
+                                                             ValueIndexTerm.TermSearchType.WILDCARD));
         }
 
         final PageResponse<RefactoringPageRow> findRulesByProjectQuery = refactoringQueryService.query(new RefactoringPageRequest(FindAllLibraryAssetsQuery.NAME,
@@ -267,7 +278,7 @@ public class LibraryServiceImpl implements LibraryService {
 
     @Override
     public Set<ExampleProject> getExampleProjects() {
-        final String importProjectsUrl = getPreferences().getImportProjectsUrl();
+        final String importProjectsUrl = getCustomImportProjectsUrl();
         final ExampleRepository repository = importProjectsUrl == null || importProjectsUrl.isEmpty()
                 ? examplesService.getPlaygroundRepository()
                 : new ExampleRepository(importProjectsUrl);
@@ -306,6 +317,20 @@ public class LibraryServiceImpl implements LibraryService {
         return new ArrayList<>(ouService.getOrganizationalUnits());
     }
 
+    @Override
+    public GAV createGAV(final String projectName,
+                         final OrganizationalUnit selectedOrganizationalUnit) {
+        final LibraryPreferences preferences = getPreferences();
+        final String artifactId = NewProjectUtils.sanitizeProjectName(projectName);
+        return new GAV(selectedOrganizationalUnit.getDefaultGroupId(),
+                       artifactId,
+                       preferences.getProjectPreferences().getVersion());
+    }
+
+    String getCustomImportProjectsUrl() {
+        return System.getProperty("org.kie.project.examples.repository.url");
+    }
+
     LibraryPreferences getPreferences() {
         preferences.load();
         return preferences;
@@ -324,14 +349,6 @@ public class LibraryServiceImpl implements LibraryService {
                        gav);
     }
 
-    GAV createGAV(final String projectName,
-                  final LibraryPreferences preferences) {
-        return new GAV(preferences.getProjectPreferences().getGroupId(),
-                       projectName.replace(" ",
-                                           ""),
-                       preferences.getProjectPreferences().getVersion());
-    }
-
     private Optional<Object> getAttribute(final String attribute,
                                           final Map<String, Object> attributes) {
         return attributes.entrySet().stream()
@@ -390,9 +407,15 @@ public class LibraryServiceImpl implements LibraryService {
             if (repositoryService.getRepository(primaryDefaultRepositoryName) == null) {
                 return createDefaultRepository(ou,
                                                primaryDefaultRepositoryName);
-            } else {
+            } else if (repositoryService.getRepository(secondaryDefaultRepositoryName) == null) {
                 return createDefaultRepository(ou,
                                                secondaryDefaultRepositoryName);
+            } else {
+                int i = 1;
+                while (repositoryService.getRepository(secondaryDefaultRepositoryName + "-" + ++i) != null) {
+                }
+                return createDefaultRepository(ou,
+                                               secondaryDefaultRepositoryName + "-" + i);
             }
         }
     }
@@ -405,6 +428,12 @@ public class LibraryServiceImpl implements LibraryService {
     }
 
     private OrganizationalUnit createDefaultOrganizationalUnit() {
+        if (!authorizationManager.authorize(OrganizationalUnit.RESOURCE_TYPE,
+                                            OrganizationalUnitAction.CREATE,
+                                            sessionInfo.getIdentity())) {
+            return null;
+        }
+
         final LibraryPreferences preferences = getPreferences();
         return ouService.createOrganizationalUnit(preferences.getOrganizationalUnitPreferences().getName(),
                                                   preferences.getOrganizationalUnitPreferences().getOwner(),
@@ -433,8 +462,13 @@ public class LibraryServiceImpl implements LibraryService {
         return getPreferences().getRepositoryPreferences().getName();
     }
 
-    private String getSecondaryDefaultRepositoryName(final OrganizationalUnit ou) {
-        return ou.getIdentifier() + "-" + getPreferences().getRepositoryPreferences().getName();
+    String getSecondaryDefaultRepositoryName(final OrganizationalUnit ou) {
+        final String sanitizedOuIdentifier = ou.getIdentifier().replaceAll("[^A-Za-z0-9]",
+                                                                           "-");
+        final String repositoryNameSuffix = getPreferences().getRepositoryPreferences().getName();
+        final String repositoryName = sanitizedOuIdentifier + "-" + repositoryNameSuffix;
+
+        return repositoryName;
     }
 
     private RepositoryEnvironmentConfigurations getDefaultRepositoryEnvironmentConfigurations() {
