@@ -27,6 +27,7 @@ import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.Package;
 import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.service.DeploymentMode;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
 import org.guvnor.structure.repositories.Repository;
@@ -275,18 +276,21 @@ public class LibraryServiceImplTest {
         final Path projectRootPath = mock(Path.class);
         when(repository.getRoot()).thenReturn(projectRootPath);
 
-        libraryService.createProject("Project Name",
+        libraryService.createProject("Project Name!",
                                      organizationalUnit,
                                      repository,
                                      "baseURL",
-                                     "description");
+                                     "description",
+                                     DeploymentMode.VALIDATED);
 
         verify(kieProjectService).newProject(eq(projectRootPath),
                                              pomArgumentCaptor.capture(),
                                              eq("baseURL"),
-                                             any());
+                                             eq(DeploymentMode.VALIDATED));
 
         final POM pom = pomArgumentCaptor.getValue();
+        assertEquals("Project Name!",
+                     pom.getName());
         assertEquals("ouGroupID",
                      pom.getGav().getGroupId());
         assertEquals("ProjectName",
@@ -493,11 +497,12 @@ public class LibraryServiceImplTest {
     }
 
     @Test
-    public void getExampleProjectsImportUrlDefinedTest() {
+    public void getCustomExampleProjectsTest() {
+        System.setProperty("org.kie.project.examples.repository.url",
+                           "importProjectsUrl");
+
         final Set<ExampleProject> exampleProjects = new HashSet<>();
         exampleProjects.add(mock(ExampleProject.class));
-
-        when(preferences.getImportProjectsUrl()).thenReturn("importProjectsUrl");
         doReturn(exampleProjects).when(examplesService).getProjects(new ExampleRepository("importProjectsUrl"));
 
         final Set<ExampleProject> loadedExampleProjects = libraryService.getExampleProjects();
@@ -507,16 +512,21 @@ public class LibraryServiceImplTest {
     }
 
     @Test
-    public void getExampleProjectsImportUrlNotDefinedTest() {
-        final ExampleRepository playgroundRepository = new ExampleRepository("playgroundRepositoryUrl");
+    public void getDefaultExampleProjectsTest() {
+        System.setProperty("org.kie.project.examples.repository.url",
+                           "");
 
-        when(preferences.getImportProjectsUrl()).thenReturn("");
+        final ExampleRepository playgroundRepository = new ExampleRepository("playgroundRepositoryUrl");
         doReturn(playgroundRepository).when(examplesService).getPlaygroundRepository();
 
-        libraryService.getExampleProjects();
+        final Set<ExampleProject> exampleProjects = new HashSet<>();
+        exampleProjects.add(mock(ExampleProject.class));
+        doReturn(exampleProjects).when(examplesService).getProjects(playgroundRepository);
 
-        verify(examplesService,
-               times(1)).getProjects(playgroundRepository);
+        final Set<ExampleProject> loadedExampleProjects = libraryService.getExampleProjects();
+
+        assertEquals(exampleProjects,
+                     loadedExampleProjects);
     }
 
     @Test
@@ -581,7 +591,6 @@ public class LibraryServiceImplTest {
         when(preferences.getProjectPreferences().getDescription()).thenReturn("desc");
 
         GAV gav = libraryService.createGAV("proj",
-                                           preferences,
                                            organizationalUnit);
         POM proj = libraryService.createPOM("proj",
                                             "description",
@@ -603,7 +612,6 @@ public class LibraryServiceImplTest {
         when(preferences.getProjectPreferences().getVersion()).thenReturn("1.0");
 
         GAV gav = libraryService.createGAV("proj",
-                                           preferences,
                                            organizationalUnit);
 
         assertEquals(organizationalUnit.getDefaultGroupId(),
