@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *        http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,13 +16,15 @@
 
 package org.kie.workbench.common.stunner.client.widgets.palette.categories.items;
 
-import org.kie.workbench.common.stunner.client.widgets.palette.factory.icons.IconRenderer;
 import org.kie.workbench.common.stunner.core.client.components.palette.model.definition.DefinitionPaletteItem;
+import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
 import org.uberfire.client.mvp.UberElement;
 
 public interface DefinitionPaletteItemWidgetView extends UberElement<DefinitionPaletteItemWidgetView.Presenter> {
 
-    void render(IconRenderer iconRenderer);
+    void render(Glyph glyph,
+                double width,
+                double height);
 
     interface Presenter {
 
