@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,8 +18,8 @@ package org.kie.workbench.common.stunner.client.widgets.palette.factory;
 
 import org.kie.workbench.common.stunner.client.widgets.palette.BS3PaletteWidget;
 import org.kie.workbench.common.stunner.client.widgets.palette.PaletteWidgetFactory;
-import org.kie.workbench.common.stunner.core.client.components.palette.model.definition.DefinitionSetPalette;
+import org.kie.workbench.common.stunner.core.client.components.palette.model.PaletteDefinition;
 
-public interface BS3PaletteFactory extends PaletteWidgetFactory<DefinitionSetPalette, BS3PaletteWidget> {
+public interface BS3PaletteFactory extends PaletteWidgetFactory<PaletteDefinition, BS3PaletteWidget<PaletteDefinition>> {
 
 }
