@@ -1,18 +1,18 @@
 /*
- * Copyright 2016 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2017 Red Hat, Inc. and/or its affiliates.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- *  
- *     http://www.apache.org/licenses/LICENSE-2.0
- *  
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.kie.workbench.common.stunner.core.client.canvas;
 
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
@@ -22,6 +22,11 @@ public class TransformImpl implements Transform {
     private final Point2D translate;
     private final Point2D scale;
 
+    public static final TransformImpl NO_TRANSFORM = new TransformImpl(new Point2D(0,
+                                                                                   0),
+                                                                       new Point2D(1,
+                                                                                   1));
+
     TransformImpl(final Point2D translate,
                   final Point2D scale) {
         this.translate = translate;
