@@ -28,6 +28,7 @@ import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.Fiel
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.type.ListBoxFieldType;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textArea.type.TextAreaFieldType;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNPropertySet;
+import org.kie.workbench.common.stunner.bpmn.forms.model.ConditionalComboBoxFieldType;
 import org.kie.workbench.common.stunner.core.definition.annotation.Name;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
@@ -61,13 +62,16 @@ public class SequenceFlowExecutionSet implements BPMNPropertySet {
 
     @Property
     @FormField(
-            type = ListBoxFieldType.class,
-            afterElement = "conditionExpression",
-            settings = {@FieldParam(name = "rows", value = "5")}
+        type = ConditionalComboBoxFieldType.class,
+        afterElement = "conditionExpression",
+        settings = {
+            @FieldParam(name = "relatedField", value = "executionSet.conditionExpression"),
+            @FieldParam(name = "allowCustomValue", value = "false")
+        }
     )
     @SelectorDataProvider(
-            type = SelectorDataProvider.ProviderType.REMOTE,
-            className = "org.kie.workbench.common.stunner.bpmn.backend.dataproviders.ScriptLanguageFormProvider")
+        type = SelectorDataProvider.ProviderType.REMOTE,
+        className = "org.kie.workbench.common.stunner.bpmn.backend.dataproviders.ConditionLanguageFormProvider")
     @Valid
     protected ConditionExpressionLanguage conditionExpressionLanguage;
 
