@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -306,7 +306,9 @@ public class AssignmentListItemWidgetViewImpl extends Composite implements Assig
     @Override
     public void setProcessVariables(final ListBoxValues processVarListBoxValues) {
         processVarComboBox.setCurrentTextValue("");
-        processVarComboBox.setListBoxValues(processVarListBoxValues);
+        ListBoxValues copyProcessVarListBoxValues = new ListBoxValues(processVarListBoxValues,
+                                                                      false);
+        processVarComboBox.setListBoxValues(copyProcessVarListBoxValues);
         String con = getConstant();
         // processVar set here because the ListBoxValues must already have been set
         if (con != null && !con.isEmpty()) {
