@@ -18,12 +18,17 @@ package org.kie.workbench.common.widgets.client.datamodel;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.TreeMap;
 import javax.enterprise.context.Dependent;
+import javax.enterprise.inject.Instance;
 import javax.inject.Inject;
+import javax.validation.ConstraintViolation;
 
 import org.drools.workbench.models.datamodel.imports.Imports;
 import org.drools.workbench.models.datamodel.oracle.Annotation;
@@ -37,9 +42,11 @@ import org.drools.workbench.models.datamodel.oracle.TypeSource;
 import org.drools.workbench.models.datamodel.rule.DSLSentence;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
+import org.jboss.errai.validation.client.dynamic.DynamicValidator;
 import org.kie.workbench.common.services.datamodel.model.LazyModelField;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleIncrementalPayload;
 import org.kie.workbench.common.services.datamodel.service.IncrementalDataModelService;
+import org.kie.workbench.common.services.datamodel.util.SortHelper;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.callbacks.Callback;
 import org.uberfire.commons.validation.PortablePreconditions;
@@ -50,8 +57,9 @@ import org.uberfire.commons.validation.PortablePreconditions;
 @Dependent
 public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOracle {
 
-    @Inject
-    protected Caller<IncrementalDataModelService> service;
+    private Caller<IncrementalDataModelService> service;
+    private Instance<DynamicValidator> validatorInstance;
+    private DynamicValidator validator;
 
     //Path that this DMO is coupled to
     private Path resourcePath;
@@ -73,7 +81,7 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
     // ####################################
 
     //Fact Types and their corresponding fields
-    protected Map<String, ModelField[]> projectModelFields = new HashMap<String, ModelField[]>();
+    protected Map<String, ModelField[]> projectModelFields = new TreeMap<String, ModelField[]>( SortHelper.ALPHABETICAL_ORDER_COMPARATOR );
 
     //Map of the field that contains the parametrized type of a collection
     //for example given "List<String> name", key = "name" value = "String"
@@ -108,7 +116,7 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
     // ####################################
 
     // Filtered (current package and imports) Fact Types and their corresponding fields
-    private Map<String, ModelField[]> filteredModelFields = new HashMap<String, ModelField[]>();
+    private Map<String, ModelField[]> filteredModelFields = new TreeMap<String, ModelField[]>( SortHelper.ALPHABETICAL_ORDER_COMPARATOR );
 
     // Filtered (current package and imports) map of the field that contains the parametrized type of a collection
     // for example given "List<String> name", key = "name" value = "String"
@@ -136,7 +144,7 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
     protected Map<String, Map<String, Set<Annotation>>> filteredTypeFieldsAnnotations = new HashMap<String, Map<String, Set<Annotation>>>();
 
     // Filtered (current package and imports) map of Globals {alias, class name}.
-    private Map<String, String> filteredGlobalTypes = new HashMap<String, String>();
+    private Map<String, String> filteredGlobalTypes = new TreeMap<String, String>( SortHelper.ALPHABETICAL_ORDER_COMPARATOR );
 
     // Package-level enumeration definitions derived from "Workbench" enumerations.
     private Map<String, String[]> packageWorkbenchEnumLists = new HashMap<String, String[]>();
@@ -151,8 +159,15 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
     // Keep the link between fact name and the full qualified class name inside the package
     private FactNameToFQCNHandleRegistry factNameToFQCNHandleRegistry = new FactNameToFQCNHandleRegistry();
 
-    //Public constructor is needed for Errai Marshaller :(
-    public AsyncPackageDataModelOracleImpl() {
+    @Inject
+    public AsyncPackageDataModelOracleImpl( final Caller<IncrementalDataModelService> service,
+                                            final Instance<DynamicValidator> validatorInstance ) {
+        this.service = service;
+        this.validatorInstance = validatorInstance;
+    }
+
+    public Map<String, ModelField[]> getFilteredFactTypes() {
+        return filteredModelFields;
     }
 
     @Override
@@ -186,7 +201,6 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
     @Override
     public String[] getFactTypes() {
         final String[] types = filteredModelFields.keySet().toArray( new String[ filteredModelFields.size() ] );
-        Arrays.sort( types );
         return types;
     }
 
@@ -200,7 +214,6 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
         types.addAll( this.projectModelFields.keySet() );
         final String[] result = new String[ types.size() ];
         types.toArray( result );
-        Arrays.sort( result );
         return result;
     }
 
@@ -220,7 +233,6 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
         }
         final String[] result = new String[ internalTypes.size() ];
         internalTypes.toArray( result );
-        Arrays.sort( result );
         return result;
     }
 
@@ -240,15 +252,12 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
         }
         final String[] result = new String[ externalTypes.size() ];
         externalTypes.toArray( result );
-        Arrays.sort( result );
         return result;
     }
 
-    public String getFQCNByFactName( final String factName ) {
-        if ( factNameToFQCNHandleRegistry.contains( factName ) ) {
-            return factNameToFQCNHandleRegistry.get( factName );
-        } else if ( factName.contains( "." ) ) {
-            return factName;
+    public String getFQCNByFactName(final String factName) {
+        if (factNameToFQCNHandleRegistry.contains(factName)) {
+            return factNameToFQCNHandleRegistry.get(factName);
         } else {
             return factName;
         }
@@ -483,6 +492,50 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
         }
     }
 
+    @Override
+    public <T> void validateField( final String factType,
+                                   final String fieldName,
+                                   final T value,
+                                   final Callback<Set<ConstraintViolation<T>>> callback ) {
+        if ( factType == null || factType.isEmpty() ) {
+            callback.callback( Collections.emptySet() );
+            return;
+        }
+        if ( fieldName == null || fieldName.isEmpty() ) {
+            callback.callback( Collections.emptySet() );
+            return;
+        }
+        if ( callback == null ) {
+            return;
+        }
+
+        if ( validatorInstance.isUnsatisfied() ) {
+            callback.callback( Collections.emptySet() );
+            return;
+
+        } else if ( validator == null ) {
+            validator = validatorInstance.get();
+        }
+
+        getTypeFieldsAnnotations( factType,
+                                  ( Map<String, Set<Annotation>> result ) -> {
+                                      final Set<ConstraintViolation<T>> violations = new HashSet<>();
+                                      final Set<Annotation> fieldAnnotations = result.get( fieldName );
+                                      if ( fieldAnnotations == null || fieldAnnotations.isEmpty() ) {
+                                          callback.callback( violations );
+                                          return;
+                                      }
+
+                                      for ( Annotation fieldAnnotation : fieldAnnotations ) {
+                                          final Map<String, Object> fieldAnnotationAttributes = fieldAnnotation.getParameters();
+                                          violations.addAll( validator.validate( fieldAnnotation.getQualifiedTypeName(),
+                                                                                 fieldAnnotationAttributes,
+                                                                                 value ) );
+                                      }
+                                      callback.callback( violations );
+                                  } );
+    }
+
     // ####################################
     // Fact Types' Fields
     // ####################################
@@ -1105,7 +1158,7 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
     public void filter() {
 
         //Filter and rename Model Fields based on package name and imports
-        filteredModelFields = new HashMap<String, ModelField[]>();
+        filteredModelFields = new TreeMap<String, ModelField[]>( SortHelper.ALPHABETICAL_ORDER_COMPARATOR );
         filteredModelFields.putAll( AsyncPackageDataModelOracleUtilities.filterModelFields( packageName,
                                                                                             imports,
                                                                                             projectModelFields,
@@ -1116,7 +1169,7 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
                                                                      factNameToFQCNHandleRegistry );
 
         //Filter and rename Global Types based on package name and imports
-        filteredGlobalTypes = new HashMap<String, String>();
+        filteredGlobalTypes = new TreeMap<String, String>( SortHelper.ALPHABETICAL_ORDER_COMPARATOR );
         filteredGlobalTypes.putAll( AsyncPackageDataModelOracleUtilities.filterGlobalTypes( packageName,
                                                                                             imports,
                                                                                             packageGlobalTypes ) );
@@ -1187,6 +1240,12 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
 
     @Override
     public void addModelFields( final Map<String, ModelField[]> modelFields ) {
+        for ( ModelField[] value : modelFields.values() ) {
+            if ( value != null ) {
+                Arrays.sort( value, getModelFieldComparator() );
+            }
+        }
+
         this.projectModelFields.putAll( modelFields );
     }
 
@@ -1207,6 +1266,12 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
 
     @Override
     public void addSuperTypes( final Map<String, List<String>> superTypes ) {
+        for ( List<String> value : superTypes.values() ) {
+            if ( value != null ) {
+                Collections.sort( value, SortHelper.ALPHABETICAL_ORDER_COMPARATOR );
+            }
+        }
+
         this.projectSuperTypes.putAll( superTypes );
     }
 
@@ -1227,6 +1292,12 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
 
     @Override
     public void addMethodInformation( final Map<String, List<MethodInfo>> methodInformation ) {
+        for ( List<MethodInfo> value : methodInformation.values() ) {
+            if ( value != null ) {
+                Collections.sort( value, getMethodInfoComparator() );
+            }
+        }
+
         this.projectMethodInformation.putAll( methodInformation );
     }
 
@@ -1237,6 +1308,7 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
 
     @Override
     public void addPackageNames( final List<String> packageNames ) {
+        Collections.sort( packageNames, SortHelper.ALPHABETICAL_ORDER_COMPARATOR );
         this.packageNames.addAll( packageNames );
     }
 
@@ -1260,4 +1332,45 @@ public class AsyncPackageDataModelOracleImpl implements AsyncPackageDataModelOra
         this.packageGlobalTypes.putAll( packageGlobalTypes );
     }
 
+    private Comparator<ModelField> getModelFieldComparator() {
+        return new Comparator<ModelField>() {
+            @Override
+            public int compare( final ModelField modelField1,
+                                final ModelField modelField2 ) {
+                return SortHelper.ALPHABETICAL_ORDER_COMPARATOR.compare( modelField1.getName(),
+                                                                         modelField2.getName() );
+            }
+        };
+    }
+
+    private Comparator<MethodInfo> getMethodInfoComparator() {
+        return new Comparator<MethodInfo>() {
+            @Override
+            public int compare( final MethodInfo methodInfo1,
+                                final MethodInfo methodInfo2 ) {
+                int result = SortHelper.ALPHABETICAL_ORDER_COMPARATOR.compare( methodInfo1.getName(),
+                                                                               methodInfo2.getName() );
+
+                if ( result == 0 ) {
+                    if ( methodInfo1.getParams() != null && methodInfo2.getParams() == null ) {
+                        return 1;
+                    } else if ( methodInfo1.getParams() == null && methodInfo2.getParams() != null ) {
+                        return -1;
+                    } else if ( methodInfo1.getParams() != null && methodInfo2.getParams() != null ) {
+                        result = methodInfo1.getParams().size() - methodInfo2.getParams().size();
+
+                        if ( result == 0 ) {
+                            for ( int i = 0; i < methodInfo1.getParams().size() && result == 0; i++ ) {
+                                result = SortHelper.ALPHABETICAL_ORDER_COMPARATOR.compare( methodInfo1.getParams().get( i ),
+                                                                                           methodInfo2.getParams().get( i ) );
+                            }
+                        }
+                    }
+                }
+
+                return result;
+            }
+        };
+    }
+
 }
