@@ -323,12 +323,34 @@ public class AsyncPackageDataModelOracleImplTest {
     }
 
     @Test
-    public void testName() throws Exception {
-        assertEquals( "org.test.Person",
-                      oracle.getFQCNByFactName( "Person" ) );
-        assertEquals( "Person",
-                      oracle.getFieldClassName( "Person",
-                                                "this" ) );
+    public void testGetFieldClassName() throws Exception {
+        assertEquals("Person",
+                     oracle.getFieldClassName("Person",
+                                              "this"));
+    }
+
+    @Test
+    public void testGetFQCNByFactNameInRegistry() throws Exception {
+        assertEquals("org.test.Person",
+                     oracle.getFQCNByFactName("Person"));
+    }
+
+    @Test
+    public void testGetFQCNByFactNameInRegistryWithPackage() throws Exception {
+        assertEquals("org.test.Person",
+                     oracle.getFQCNByFactName("org.test.Person"));
+    }
+
+    @Test
+    public void testGetFQCNByFactNameUnknown() throws Exception {
+        assertEquals("UnknownPerson",
+                     oracle.getFQCNByFactName("UnknownPerson"));
+    }
+
+    @Test
+    public void testGetFQCNByFactNameUnknownWithPackage() throws Exception {
+        assertEquals("org.test.UnknownPerson",
+                     oracle.getFQCNByFactName("org.test.UnknownPerson"));
     }
 
     @Test
@@ -420,8 +442,8 @@ public class AsyncPackageDataModelOracleImplTest {
         Callback<String[]> callback = spy(new Callback<String[]>() {
             @Override
             public void callback(String[] result) {
-                assertArrayEquals( new String[] { "==", "!=", "<", ">", "<=", ">=", "matches", "soundslike", "== null", "!= null",  "in", "not in" },
-                                   result );
+                assertArrayEquals(new String[]{"==", "!=", "<", ">", "<=", ">=", "matches", "not matches", "soundslike", "not soundslike", "== null", "!= null", "in", "not in"},
+                                  result);
             }
         });
 
