@@ -15,22 +15,28 @@
 
 package org.kie.workbench.common.widgets.client.datamodel;
 
+import javax.enterprise.inject.Instance;
+
 import org.drools.workbench.models.datamodel.oracle.DataType;
 import org.drools.workbench.models.datamodel.oracle.FieldAccessorsAndMutators;
 import org.drools.workbench.models.datamodel.oracle.ModelField;
 import org.drools.workbench.models.datamodel.oracle.PackageDataModelOracle;
 import org.drools.workbench.models.datamodel.oracle.ProjectDataModelOracle;
 import org.jboss.errai.common.client.api.Caller;
+import org.jboss.errai.validation.client.dynamic.DynamicValidator;
 import org.junit.Test;
 import org.kie.workbench.common.services.datamodel.backend.server.builder.packages.PackageDataModelOracleBuilder;
 import org.kie.workbench.common.services.datamodel.backend.server.builder.projects.ProjectDataModelOracleBuilder;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
 import org.kie.workbench.common.services.datamodel.service.IncrementalDataModelService;
+import org.mockito.Mock;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.callbacks.Callback;
 
-import static org.junit.Assert.*;
-import static org.kie.workbench.common.widgets.client.datamodel.PackageDataModelOracleTestUtils.*;
+import javax.enterprise.inject.Instance;
+
+import static org.junit.Assert.assertEquals;
+import static org.kie.workbench.common.widgets.client.datamodel.PackageDataModelOracleTestUtils.assertContains;
 import static org.mockito.Mockito.*;
 
 /**
@@ -38,6 +44,9 @@ import static org.mockito.Mockito.*;
  */
 public class PackageDataModelOracleCompletionsTest {
 
+    @Mock
+    private Instance<DynamicValidator> validatorInstance;
+
     @Test
     public void testFactsAndFields() {
         final ProjectDataModelOracle projectLoader = ProjectDataModelOracleBuilder.newProjectOracleBuilder()
@@ -60,9 +69,9 @@ public class PackageDataModelOracleCompletionsTest {
         final PackageDataModelOracle packageLoader = PackageDataModelOracleBuilder.newPackageOracleBuilder().setProjectOracle( projectLoader ).build();
 
         //Emulate server-to-client conversions
-        final MockAsyncPackageDataModelOracleImpl oracle = new MockAsyncPackageDataModelOracleImpl();
         final Caller<IncrementalDataModelService> service = new MockIncrementalDataModelServiceCaller( packageLoader );
-        oracle.setService( service );
+        final AsyncPackageDataModelOracle oracle = new AsyncPackageDataModelOracleImpl( service,
+                                                                                        validatorInstance );
 
         final PackageDataModelOracleBaselinePayload dataModel = new PackageDataModelOracleBaselinePayload();
         dataModel.setPackageName( packageLoader.getPackageName() );
@@ -122,9 +131,9 @@ public class PackageDataModelOracleCompletionsTest {
         final PackageDataModelOracle packageLoader = PackageDataModelOracleBuilder.newPackageOracleBuilder().setProjectOracle( projectLoader ).build();
 
         //Emulate server-to-client conversions
-        final MockAsyncPackageDataModelOracleImpl oracle = new MockAsyncPackageDataModelOracleImpl();
         final Caller<IncrementalDataModelService> service = new MockIncrementalDataModelServiceCaller( packageLoader );
-        oracle.setService( service );
+        final AsyncPackageDataModelOracle oracle = new AsyncPackageDataModelOracleImpl( service,
+                                                                                        validatorInstance );
 
         final PackageDataModelOracleBaselinePayload dataModel = new PackageDataModelOracleBaselinePayload();
         dataModel.setPackageName( packageLoader.getPackageName() );
@@ -171,9 +180,9 @@ public class PackageDataModelOracleCompletionsTest {
         final PackageDataModelOracle packageLoader = PackageDataModelOracleBuilder.newPackageOracleBuilder().setProjectOracle( projectLoader ).build();
 
         //Emulate server-to-client conversions
-        final MockAsyncPackageDataModelOracleImpl oracle = new MockAsyncPackageDataModelOracleImpl();
         final Caller<IncrementalDataModelService> service = new MockIncrementalDataModelServiceCaller( packageLoader );
-        oracle.setService( service );
+        final AsyncPackageDataModelOracle oracle = new AsyncPackageDataModelOracleImpl( service,
+                                                                                        validatorInstance );
 
         final PackageDataModelOracleBaselinePayload dataModel = new PackageDataModelOracleBaselinePayload();
         dataModel.setPackageName( packageLoader.getPackageName() );
@@ -188,13 +197,13 @@ public class PackageDataModelOracleCompletionsTest {
             public void callback( final ModelField[] fields ) {
                 assertEquals( 4,
                               fields.length );
-                assertEquals( "this",
-                              fields[ 0 ].getName() );
                 assertEquals( "age",
+                              fields[ 0 ].getName() );
+                assertEquals( "name",
                               fields[ 1 ].getName() );
                 assertEquals( "rank",
                               fields[ 2 ].getName() );
-                assertEquals( "name",
+                assertEquals( "this",
                               fields[ 3 ].getName() );
             }
         } );
@@ -233,9 +242,9 @@ public class PackageDataModelOracleCompletionsTest {
         final PackageDataModelOracle packageLoader = PackageDataModelOracleBuilder.newPackageOracleBuilder().setProjectOracle( projectLoader ).build();
 
         //Emulate server-to-client conversions
-        final MockAsyncPackageDataModelOracleImpl oracle = new MockAsyncPackageDataModelOracleImpl();
         final Caller<IncrementalDataModelService> service = new MockIncrementalDataModelServiceCaller( packageLoader );
-        oracle.setService( service );
+        final AsyncPackageDataModelOracle oracle = new AsyncPackageDataModelOracleImpl( service,
+                                                                                        validatorInstance );
 
         final PackageDataModelOracleBaselinePayload dataModel = new PackageDataModelOracleBaselinePayload();
         dataModel.setPackageName( packageLoader.getPackageName() );
@@ -331,7 +340,7 @@ public class PackageDataModelOracleCompletionsTest {
         Callback<String[]> personNameCallback = spy( new Callback<String[]>() {
             @Override
             public void callback( final String[] personNameOperators ) {
-                assertEquals( 12,
+                assertEquals( 14,
                               personNameOperators.length );
                 assertEquals( "==",
                               personNameOperators[ 0 ] );
@@ -346,17 +355,21 @@ public class PackageDataModelOracleCompletionsTest {
                 assertEquals( ">=",
                               personNameOperators[ 5 ] );
                 assertEquals( "matches",
-                              personNameOperators[ 6 ] );
+                              personNameOperators[ 6 ]);
+                assertEquals( "not matches",
+                              personNameOperators[ 7 ]);
                 assertEquals( "soundslike",
-                              personNameOperators[ 7 ] );
+                              personNameOperators[ 8 ]);
+                assertEquals( "not soundslike",
+                              personNameOperators[ 9 ]);
                 assertEquals( "== null",
-                              personNameOperators[ 8 ] );
+                              personNameOperators[ 10 ]);
                 assertEquals( "!= null",
-                              personNameOperators[ 9 ] );
-                assertEquals( "in",
-                              personNameOperators[ 10 ] );
-                assertEquals( "not in",
                               personNameOperators[ 11 ] );
+                assertEquals( "in",
+                              personNameOperators[ 12 ] );
+                assertEquals( "not in",
+                              personNameOperators[ 13 ] );
             }
         } );
         oracle.getOperatorCompletions( "Person",
@@ -394,9 +407,9 @@ public class PackageDataModelOracleCompletionsTest {
         final PackageDataModelOracle packageLoader = PackageDataModelOracleBuilder.newPackageOracleBuilder().setProjectOracle( projectLoader ).build();
 
         //Emulate server-to-client conversions
-        final MockAsyncPackageDataModelOracleImpl oracle = new MockAsyncPackageDataModelOracleImpl();
         final Caller<IncrementalDataModelService> service = new MockIncrementalDataModelServiceCaller( packageLoader );
-        oracle.setService( service );
+        final AsyncPackageDataModelOracle oracle = new AsyncPackageDataModelOracleImpl( service,
+                                                                                        validatorInstance );
 
         final PackageDataModelOracleBaselinePayload dataModel = new PackageDataModelOracleBaselinePayload();
         dataModel.setPackageName( packageLoader.getPackageName() );
